
import ctypes

def init(lib):
	lib.erbool_get.restype = ctypes.c_char # else c_int is default #lib.erbool_get.argtypes is for at least, not equal or at most
	#erbool_reset

	#freereset

	lib.xlog_pad_get.restype = ctypes.c_ubyte
	lib.xlog_pad_set.argtypes = [ctypes.c_ubyte]

	global _lib
	_lib=lib

def erbool_get(): #this to enforce no arguments
	return _lib.erbool_get()
def erbool_reset():
	_lib.erbool_reset()

def freereset():
	_lib.freereset()

def xlog_pad_get():
	return _lib.xlog_pad_get()
def xlog_pad_set(new_pad):
	_lib.xlog_pad_set(new_pad)




import ctypes


class ButtonData(ctypes.Structure):
	pass
ButtonData._fields_ = [("def_fill", ctypes.c_uint)
				,("def_line_sz", ctypes.c_int)
				,("def_line", ctypes.c_uint)

				,("ov_fill", ctypes.c_uint)
				,("ov_line_sz", ctypes.c_int)
				,("ov_line", ctypes.c_uint)

				,("dn_fill", ctypes.c_uint)
				,("dn_line_sz", ctypes.c_int)
				,("dn_line", ctypes.c_uint)

				,("xcurve", ctypes.c_int)
				,("ycurve", ctypes.c_int)

				,("text", ctypes.c_char_p)
				,("font_id", ctypes.c_int)
				,("font_height", ctypes.c_int)
				,("font_vertical_offset", ctypes.c_int)
				,("font_color", ctypes.c_int)

				,("actions", ctypes.c_char_p)]
ButtonData._pack_ = 4

class EditText(ctypes.Structure):
	pass
EditText._fields_ = [("fontid", ctypes.c_int)
				,("font_height", ctypes.c_int)
				,("fontclassname", ctypes.c_char_p)
				,("rgba", ctypes.c_int)
				,("maxlength", ctypes.c_int)
				,("initialtext", ctypes.c_char_p)
				,("layout_align", ctypes.c_int)
				,("layout_leftmargin", ctypes.c_int)
				,("layout_rightmargin", ctypes.c_int)
				,("layout_indent", ctypes.c_int)
				,("layout_leading", ctypes.c_int)]
EditText._pack_ = 4

def init(lib):
	lib.swf_button.argtypes = [ctypes.c_int,ctypes.c_int,ctypes.POINTER(ButtonData)] #lib.swf_button.restype = c_int #https://docs.python.org/3/library/ctypes.html: By default functions are assumed to return the C int type.
	lib.swf_button_last.argtypes = [ctypes.c_char_p,ctypes.c_char_p] #lib.swf_button_last.restype = c_int

	lib.swf_font.argtypes = [ctypes.c_char_p,ctypes.c_char] #lib.swf_font.restype = c_int
	lib.swf_font_basic.argtypes = [ctypes.c_char_p] #lib.swf_font_basic.restype = c_int

	lib.swf_text.argtypes = [ctypes.c_int,ctypes.c_int,ctypes.c_char_p,ctypes.c_short,ctypes.POINTER(EditText)] #lib.swf_text.restype = c_int

	lib.swf_shape.argtypes = [ctypes.c_int,ctypes.c_int,ctypes.POINTER(ctypes.c_int)] #lib.swf_shape.restype = c_int  # (ctypes.c_int * 2)(*[4, 5])
	lib.swf_shape_basic.argtypes = [ctypes.c_int,ctypes.c_int,ctypes.c_int,ctypes.c_int] #lib.swf_shape_basic.restype = c_int
	lib.swf_shape_bitmap.argtypes = [ctypes.c_int,ctypes.c_int,ctypes.c_int] #lib.swf_shape_bitmap.restype = c_int
	lib.swf_shape_bitmap_clipped.argtypes = [ctypes.c_int,ctypes.c_int,ctypes.c_int] #lib.swf_shape_bitmap_clipped.restype = c_int
	lib.swf_shape_border.argtypes = [ctypes.c_int,ctypes.c_int,ctypes.c_int,ctypes.c_int] #lib.swf_shape_border.restype = c_int

	lib.swf_image.argtypes = [ctypes.c_char_p] #lib.swf_image.restype = c_int
	lib.swf_image_ex.argtypes = [ctypes.c_char_p,ctypes.POINTER(ctypes.c_int)] #lib.swf_image.restype = c_int  # (ctypes.c_int * 2)()
	lib.swf_dbl.argtypes = [ctypes.c_char_p] #lib.swf_dbl.restype = c_int
	lib.swf_dbl_ex.argtypes = [ctypes.c_char_p,ctypes.POINTER(ctypes.c_int)] #lib.swf_dbl_ex.restype = c_int
	lib.swf_dbl_width.argtypes = [ctypes.c_char_p] #lib.swf_dbl_width.restype = c_int
	lib.swf_dbl_height.argtypes = [ctypes.c_char_p] #lib.swf_dbl_height.restype = c_int

	lib.swf_imagej.argtypes = [ctypes.c_char_p,ctypes.c_int,ctypes.c_int] #lib.swf_imagej.restype = c_int
	lib.swf_imagej_alpha.argtypes = [ctypes.c_char_p,ctypes.c_int,ctypes.c_int,ctypes.c_char_p] #lib.swf_imagej_alpha.restype = c_int
	lib.swf_imagej_clipped.argtypes = [ctypes.c_char_p,ctypes.c_int,ctypes.c_int] #lib.swf_imagej_clipped.restype = c_int
	lib.swf_imagej_alpha_clipped.argtypes = [ctypes.c_char_p,ctypes.c_int,ctypes.c_int,ctypes.c_char_p] #lib.swf_imagej_alpha_clipped.restype = c_int
	lib.swf_jpeg.argtypes = [ctypes.c_char_p] #lib.swf_jpeg.restype = c_int
	lib.swf_jpeg_alpha.argtypes = [ctypes.c_char_p,ctypes.c_char_p] #lib.swf_jpeg_alpha.restype = c_int
	lib.swf_gif_width.argtypes = [ctypes.c_char_p] #lib.swf_gif_width.restype = c_int
	lib.swf_gif_height.argtypes = [ctypes.c_char_p] #lib.swf_gif_height.restype = c_int

	lib.swf_imagex.argtypes = [ctypes.c_char_p] #lib.swf_imagex.restype = c_int
	lib.swf_imagex_ex.argtypes = [ctypes.c_char_p,ctypes.POINTER(ctypes.c_int)] #lib.swf_imagex_ex.restype = c_int
	lib.swf_img.argtypes = [ctypes.c_char_p] #lib.swf_img.restype = c_int
	lib.swf_img_ex.argtypes = [ctypes.c_char_p,ctypes.POINTER(ctypes.c_int)] #lib.swf_img_ex.restype = c_int

	#swf_done
	lib.swf_new.argtypes = [ctypes.c_char_p,ctypes.c_int,ctypes.c_int,ctypes.c_int,ctypes.c_ubyte] #lib.swf_new.restype = None # else c_int is default , is ok, there is still a wrapper to enforce nr of args
	lib.swf_new_ex.argtypes = [ctypes.c_char_p,ctypes.c_int,ctypes.c_int,ctypes.c_int,ctypes.c_ubyte,ctypes.c_int]
	lib.swf_placeobject.argtypes = [ctypes.c_int,ctypes.c_int]
	lib.swf_placeobject_coords.argtypes = [ctypes.c_int,ctypes.c_int,ctypes.c_int,ctypes.c_int]
	lib.swf_removeobject.argtypes = [ctypes.c_int]
	#swf_showframe

	lib.swf_sprite_done.argtypes = [ctypes.c_int] #lib.swf_sprite_done.restype = c_int
	#lib.swf_sprite_new.restype = c_int
	lib.swf_sprite_placeobject.argtypes = [ctypes.c_int,ctypes.c_int,ctypes.c_int]
	lib.swf_sprite_placeobject_coords.argtypes = [ctypes.c_int,ctypes.c_int,ctypes.c_int,ctypes.c_int,ctypes.c_int]
	lib.swf_sprite_removeobject.argtypes = [ctypes.c_int,ctypes.c_int]
	lib.swf_sprite_showframe.argtypes = [ctypes.c_int]

	lib.swf_exports_add.argtypes = [ctypes.c_int,ctypes.c_char_p]
	#swf_exports_done

	global _lib
	_lib=lib

def button(width,height,buttondata):
	return _lib.swf_button(width,height,buttondata)
def button_last(actions,newtext):
	return _lib.swf_button_last(actions,newtext)

def font(fontname,font_flags):
	return _lib.swf_font(fontname,font_flags)
def font_basic(fontname):
	return _lib.swf_font_basic(fontname)

def text(bound_width,bound_height,variablename,flags,structure):
	return _lib.swf_text(bound_width,bound_height,variablename,flags,structure)

def shape(width,height,args):
	return _lib.swf_shape(width,height,args)
def shape_basic(width,height,fillcolor,linecolor):
	return _lib.swf_shape_basic(width,height,fillcolor,linecolor)
def shape_bitmap(bitmapId,width,height):
	return _lib.swf_shape_bitmap(bitmapId,width,height)
def shape_bitmap_clipped(bitmapId,width,height):
	return _lib.swf_shape_bitmap_clipped(bitmapId,width,height)
def shape_border(width,height,linesize,linecolor):
	return _lib.swf_shape_border(width,height,linesize,linecolor)

def image(imagepath):
	return _lib.swf_image(imagepath)
def image_ex(imagepath,wh):
	return _lib.swf_image_ex(imagepath,wh)
def dbl(imagepath):
	return _lib.swf_dbl(imagepath)
def dbl_ex(imagepath,wh):
	return _lib.swf_dbl_ex(imagepath,wh)
def dbl_width(imagepath):
	return _lib.swf_dbl_width(imagepath)
def dbl_height(imagepath):
	return _lib.swf_dbl_height(imagepath)

def imagej(imagepath,width,height):
	return _lib.swf_imagej(imagepath,width,height)
def imagej_alpha(imagepath,width,height,alphapath):
	return _lib.swf_imagej_alpha(imagepath,width,height,alphapath)
def imagej_clipped(imagepath,width,height):
	return _lib.swf_imagej_clipped(imagepath,width,height)
def imagej_alpha_clipped(imagepath,width,height,alphapath):
	return _lib.swf_imagej_alpha_clipped(imagepath,width,height,alphapath)
def jpeg(imagepath):
	return _lib.swf_jpeg(imagepath)
def jpeg_alpha(imagepath,alphapath):
	return _lib.swf_jpeg_alpha(imagepath,alphapath)
def gif_width(imagepath):
	return _lib.swf_gif_width(imagepath)
def gif_height(imagepath):
	return _lib.swf_gif_height(imagepath)

def imagex(imagepath):
	return _lib.swf_imagex(imagepath)
def imagex_ex(imagepath,wh):
	return _lib.swf_imagex_ex(imagepath,wh)
def img(imagepath):
	return _lib.swf_img(imagepath)
def img_ex(imagepath,wh):
	return _lib.swf_img_ex(imagepath,wh)

def done():
	_lib.swf_done()
def new(path,width,height,backgroundcolor,fps):
	_lib.swf_new(path,width,height,backgroundcolor,fps)
def new_ex(path,width,height,backgroundcolor,fps,flags):
	_lib.swf_new_ex(path,width,height,backgroundcolor,fps,flags)
def placeobject(refid,depth):
	_lib.swf_placeobject(refid,depth)
def placeobject_coords(refid,depth,x,y):
	_lib.swf_placeobject_coords(refid,depth,x,y)
def removeobject(depth):
	_lib.swf_removeobject(depth)
def showframe():
	_lib.swf_showframe()

def sprite_done(spriteid):
	return _lib.swf_sprite_done(spriteid)
def sprite_new():
	return _lib.swf_sprite_new()
def sprite_placeobject(spriteid,object,depth):
	_lib.swf_sprite_placeobject(spriteid,object,depth)
def sprite_placeobject_coords(spriteid,object,depth,x,y):
	_lib.swf_sprite_placeobject_coords(spriteid,object,depth,x,y)
def sprite_removeobject(spriteid,depth):
	_lib.swf_sprite_removeobject(spriteid,depth)
def sprite_showframe(spriteid):
	_lib.swf_sprite_showframe(spriteid)

def exports_add(id,name):
	_lib.swf_exports_add(id,name)
def exports_done():
	_lib.swf_exports_done()




from enum import IntEnum

class flag(IntEnum):
	none=            0
	pre_log=         0x1
	alt=             0x2
	titles=          0x4
	pre_x=           0x8
	pre_x_pad=       0x10
	forin1=          0x20
	framesAsShows=   0x40
	x=               0x80
	pre_pool_write=  0x100
	pool_read=       0x200
	pre_mix=         0x400
	pool_read_unlink=0x800
	pre_write_no=    0x1000
	compress=        0x2000
	deprecation_no=  0x4000
	deprecation_yes= 0x8000
	noDuplicate=     0x10000
	verbose=         0x20000
	xx=              0x40000
class flags(IntEnum):
	pool=        flag.pre_pool_write|flag.pool_read
	x=           flag.pre_x|flag.x
	prex=        flag.pre_log|flag.pre_pool_write|flag.pre_x
	prexx=       prex|flag.xx
	antix_read=  flag.pre_log|flag.alt|flag.pre_x
	antixx_write=flag.titles
	xx=          flag.pool_read|flag.xx
class flagss(IntEnum):
	x=        flag.x|flag.pool_read
	xu=       x|flag.pool_read_unlink
	xx=       x|flag.xx
	xxu=      xu|flag.xx
	read_done=flag.pool_read|flag.pool_read_unlink

class FILLSTYLE(IntEnum):
	no=                          -1
	solid=                       0
	repeating_bitmap=            0x40
	clipped_bitmap=              0x41
	nonsmoothed_repeating_bitmap=0x42
	nonsmoothed_clipped_bitmap=  0x43
class State(IntEnum):
	MoveTo=    1
	FillStyle0=1 << 1
	FillStyle1=1 << 2
	LineStyle= 1 << 3
	NewStyles= 1 << 4
class ButtonState(IntEnum):
	Up=     1
	Over=   1 << 1
	Down=   1 << 2
	HitTest=1 << 3

class Text(IntEnum):
	HasText=     0x80
	WordWrap=    0x40
	Multiline=   0x20
	Password=    0x10
	ReadOnly=    0x8
	HasTextColor=0x4
	HasMaxLength=0x2
	HasFont=     0x1
	HasFontClass=0x8000
	AutoSize=    0x4000
	HasLayout=   0x2000
	NoSelect=    0x1000
	Border=      0x800
	WasStatic=   0x400
	HTML=        0x200
	UseOutlines= 0x100
class LayoutAlign(IntEnum):
	left=   0
	right=  1
	center= 2
	justify=3

class FontFlags(IntEnum):
	HasLayout=           0x80
	FontFlagsShiftJIS=   0x40
	FontFlagsSmallText=  0x20
	FontFlagsANSI=       0x10
	FontFlagsWideOffsets=8
	FontFlagsWideCodes=  4
	FontFlagsItalic=     2
	FontFlagsBold=       1


import ctypes

#try: #in PATH
_lib=ctypes.cdll.LoadLibrary("libactionswf.so")
#except Exception:
#lib=ctypes.cdll.LoadLibrary("actionswf.dll")

from . import _swf
_swf.init(_lib)
ButtonData=_swf.ButtonData
EditText=_swf.EditText
button=_swf.button
button_last=_swf.button_last
font=_swf.font
font_basic=_swf.font_basic
text=_swf.text
shape=_swf.shape
shape_basic=_swf.shape_basic
shape_bitmap=_swf.shape_bitmap
shape_bitmap_clipped=_swf.shape_bitmap_clipped
shape_border=_swf.shape_border
image=_swf.image
image_ex=_swf.image_ex
dbl=_swf.dbl
dbl_ex=_swf.dbl_ex
dbl_width=_swf.dbl_width
dbl_height=_swf.dbl_height
imagej=_swf.imagej
imagej_alpha=_swf.imagej_alpha
imagej_clipped=_swf.imagej_clipped
imagej_alpha_clipped=_swf.imagej_alpha_clipped
jpeg=_swf.jpeg
jpeg_alpha=_swf.jpeg_alpha
gif_width=_swf.gif_width
gif_height=_swf.gif_height
imagex=_swf.imagex
imagex_ex=_swf.imagex_ex
img=_swf.img
img_ex=_swf.img_ex
done=_swf.done
new=_swf.new
new_ex=_swf.new_ex
placeobject=_swf.placeobject
placeobject_coords=_swf.placeobject_coords
removeobject=_swf.removeobject
showframe=_swf.showframe
sprite_done=_swf.sprite_done
sprite_new=_swf.sprite_new
sprite_placeobject=_swf.sprite_placeobject
sprite_placeobject_coords=_swf.sprite_placeobject_coords
sprite_removeobject=_swf.sprite_removeobject
sprite_showframe=_swf.sprite_showframe
exports_add=_swf.exports_add
exports_done=_swf.exports_done

from . import _action
_action.init(_lib)
action=_action.action
actionf=_action.actionf
actiond=_action.actiond
action_sprite=_action.action_sprite
actionf_sprite=_action.actionf_sprite
action_init_sprite=_action.action_init_sprite
actionf_init_sprite=_action.actionf_init_sprite

from . import _tool
_tool.init(_lib)
erbool_get=_tool.erbool_get
erbool_reset=_tool.erbool_reset
freereset=_tool.freereset
xlog_pad_get=_tool.xlog_pad_get
xlog_pad_set=_tool.xlog_pad_set




import ctypes

def init(lib):
	lib.action.argtypes = [ ctypes.c_char_p ]
	lib.actionf.argtypes = [ ctypes.c_char_p, ctypes.c_char_p ]
	lib.actiond.argtypes = [ ctypes.c_char_p ]

	lib.action_sprite.argtypes = [ ctypes.c_int, ctypes.c_char_p ]
	lib.actionf_sprite.argtypes = [ ctypes.c_int, ctypes.c_char_p, ctypes.c_char_p ]
	lib.action_init_sprite.argtypes = [ ctypes.c_int, ctypes.c_char_p ]
	lib.actionf_init_sprite.argtypes = [ ctypes.c_int, ctypes.c_char_p, ctypes.c_char_p ]

	global _lib
	_lib=lib

def action(ac):
	_lib.action(ac)
def actionf(*args, buffer, format): #You must place the variadic ones first in the function definition  #call this like this: (buffer=b, format="...", *["a",1])
	_lib.actionf(buffer, format, *args)
def actiond(ac):
	_lib.actiond(ac)

def action_sprite(sprite, ac):
	_lib.action_sprite(sprite, ac)
def actionf_sprite(*args, sprite, buffer, format):
	_lib.actionf_sprite(sprite, buffer, format, *args)
def action_init_sprite(sprite, ac):
	_lib.action_init_sprite(sprite, ac)
def actionf_init_sprite(*args, sprite, buffer, format):
	_lib.actionf_init_sprite(sprite, buffer, format, *args)



ver="1.1"
README="""ActionSwf bindings.\\
[Git Page](https://github.com/colin-i/actionswf)
"""

#this file will make setup.py after using github colin-i test/pyp/pypre

pkname='actionswf'

from setuptools import setup
setup(name=pkname,
	version=ver,
	packages=[pkname],
	#opt
	python_requires='>=3',
	#install_requires=["appdirs>=1","b"],
	#extras_require={'bin': ['a>=1'],},
	description='ActionSwf bindings',
	long_description=README,
	long_description_content_type="text/markdown",
	url='https://github.com/colin-i/actionswf',
	author='cb',
	author_email='costin.botescu@gmail.com',
	license='MIT'
)
